==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebButtonBaseDescriptionMetadata } from "./WebButtonBaseDescriptionMetadata";
import { WebButtonDescription } from "./WebButtonDescription";
/**
 * @hidden
 */
export let WebButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebButtonDescriptionMetadata extends Base {
        static b(a) {
            if (WebButtonDescriptionMetadata.a == null) {
                WebButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebButtonDescriptionMetadata.c(WebButtonDescriptionMetadata.a);
            }
            if (a.k(WebButtonDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebButtonDescriptionMetadata.a);
        }
        static c(a) {
            WebButtonBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Button");
            a.item("__tagNameWC", "String:igc-button");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Variant", "ExportedType:string:ButtonVariant");
            a.item("Variant@stringUnion", "WebComponents;React");
            a.item("Variant@names", "Flat;Contained;Outlined;Fab");
        }
        static d(a) {
            WebButtonDescriptionMetadata.b(a);
            a.ad("WebButton", () => new WebButtonDescription());
            a.ac("WebButton", WebButtonDescriptionMetadata.a);
        }
    }
    WebButtonDescriptionMetadata.$t = markType(WebButtonDescriptionMetadata, 'WebButtonDescriptionMetadata');
    WebButtonDescriptionMetadata.a = null;
    return WebButtonDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebButtonBaseDescriptionMetadata } from "./WebButtonBaseDescriptionMetadata";
import { WebButtonDescription } from "./WebButtonDescription";
/**
 * @hidden
 */
export let WebButtonDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebButtonDescriptionMetadata extends Base {
        static b(a) {
            if (WebButtonDescriptionMetadata.a == null) {
                WebButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebButtonDescriptionMetadata.c(WebButtonDescriptionMetadata.a);
            }
            if (a.k(WebButtonDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebButtonDescriptionMetadata.a);
        }
        static c(a) {
            WebButtonBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Button");
            a.item("__tagNameWC", "String:igc-button");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Variant", "ExportedType:string:ButtonVariant");
            a.item("Variant@stringUnion", "WebComponents;React");
            a.item("Variant@names", "Contained;Flat;Outlined;Fab");
        }
        static d(a) {
            WebButtonDescriptionMetadata.b(a);
            a.ae("WebButton", () => new WebButtonDescription());
            a.ad("WebButton", WebButtonDescriptionMetadata.a);
        }
    }
    WebButtonDescriptionMetadata.$t = markType(WebButtonDescriptionMetadata, 'WebButtonDescriptionMetadata');
    WebButtonDescriptionMetadata.a = null;
    return WebButtonDescriptionMetadata;
})();
